@@ -25,13 +25,15 @@ class ColorFormatter(logging.Formatter):
     def format(self, record):
         """Format the record with colors."""
         message = logging.Formatter.format(self, record)
-        return ('\x1b[0m' +
+        if sys.version_info[0] < 3:
+            if isinstance(message, unicode):
+                message = message.encode('utf-8')
+        return ('\x1b[0m%s\x1b[0m' %
                 message
-                   .replace('$RESET', '\x1b[0m')
-                   .replace('$BOLD', '\x1b[1m')
-                   .replace('$COLOR', '\x1b[%dm' %
-                            self.level_colors.get(record.levelname, 37)) +
-                '\x1b[0m')
+                .replace('$RESET', '\x1b[0m')
+                .replace('$BOLD', '\x1b[1m')
+                .replace('$COLOR', '\x1b[%dm' %
+                         self.level_colors.get(record.levelname, 37)))
 
 
 def make_colored_stream_handler(
@@ -39,7 +41,12 @@ def make_colored_stream_handler(
     """Return a colored stream handler"""
     handler = logging.StreamHandler(std)
     handler.setLevel(level)
-    if not hasattr(std, 'fileno') or os.isatty(std.fileno()):
+    try:
+        fn = std.fileno()
+    except:
+        fn = None
+
+    if fn == None or os.isatty(fn):
         handler.setFormatter(
             ColorFormatter(
                 '$COLOR%(asctime)s $BOLD$COLOR%(name)s'
